# Changelog


## v0.6.0 (2022-12-17)

* Link to API docs.

* Add API docs.

* Add export.

* Bump requirements to python 3.8 or higher.

* Document methods.

* Remove unused import.

* Docs: add @WyattBlue as a contributor.

* Docs: add @slhck as a contributor.

* Unhide to_ms.

* Add type hints + simplify.

* Add python CI badge.

* Fix quit tests.

* Add all-contributors.

* Add pytest to dev requirements.

* Add github workflows.

* Formatting.

* Fix a few type and formatting errors.


## v0.5.0 (2022-12-12)

* Add stderr callback method.

* Update README.

* Add graceful quit method.

* Add a GIF in the readme.


## v0.4.0 (2022-12-11)

* Add a quit method, fixes #4.


## v0.3.0 (2022-08-02)

* Update python requirements.


## v0.2.0 (2021-11-21)

* Add a usage option.


## v0.1.2 (2021-08-14)

* Remove universal_newlines for Windows compat.


## v0.1.1 (2021-07-01)

* Remove stats_period option for backwards compatibility, fixes #2.


## v0.1.0 (2021-06-30)

* Format code with black.

* Yield 0 in progress and improve logic.

* Set universal_newlines to true and add kwargs support.

* Increase stats period.

* Document method.

* Add typing.

* Also check for 0 in output.

* Update gitignore.

* Drop python 3.5 support.

* Update badge link.


## v0.0.4 (2021-03-10)

* Add python_requires to setup.py.


## v0.0.3 (2021-03-06)

* Remove release script.


## v0.0.2 (2021-03-06)

* Fix release script.

* Remove support for older versions.

* Format setup.py.

* Remove requirement for command to start with ffmpeg.

* Add link to similar project.

* Add changelog.

* Rename project.

* Initial commit.


